//
//  ViewController.swift
//  Notities
//
//  Created by Developer on 31-03-17.
//  Copyright © 2017 iOS Academie. All rights reserved.
//

import UIKit

class ViewController: UIViewController, UITableViewDataSource, UITableViewDelegate {
  
  @IBOutlet weak var searchBar: UISearchBar!
  @IBOutlet weak var tableView: UITableView!

  override func viewDidLoad() {
    super.viewDidLoad()
    // Do any additional setup after loading the view, typically from a nib.
  }

  override func didReceiveMemoryWarning() {
    super.didReceiveMemoryWarning()
    // Dispose of any resources that can be recreated.
  }
  
  func wijzig(notitie: Notitie) {
    if let titel = notitie.titel {
      let alert = UIAlertController(title: "Wijzig notitie", message: nil, preferredStyle: .alert)
      alert.addTextField()
      alert.textFields?.first?.text = titel
      alert.addAction(UIAlertAction(title: "Annuleer", style: .cancel))
      alert.addAction(UIAlertAction(title: "OK", style: .default) {
        actie in
        if let titel = alert.textFields?.last?.text {
          Model.shared.wijzig(titel: titel, voor: notitie)
          self.tableView.reloadData()
        }
      })
      self.present(alert, animated: true)
    }
  }
  
  func verwijder(notitie: Notitie) {
    if let titel = notitie.titel {
      let alert = UIAlertController(title: nil, message: titel, preferredStyle: .actionSheet)
      alert.addAction(UIAlertAction(title: "Annuleer", style: .cancel))
      alert.addAction(UIAlertAction(title: "Verwijder", style: .destructive) {
        actie in
        Model.shared.verwijder(notitie: notitie)
        self.tableView.reloadData()
      })
      self.present(alert, animated: true)
    }
  }


  @IBAction func maakItem(_ sender: Any) {
    let alert = UIAlertController(title: "Nieuwe notitie", message: nil, preferredStyle: .alert)
    alert.addTextField()
    alert.addAction(UIAlertAction(title: "Annuleer", style: .cancel))
    alert.addAction(UIAlertAction(title: "OK", style: .default) {
      actie in
      if let titel = alert.textFields?.last?.text {
        Model.shared.maakNotitie(titel: titel)
        self.tableView.reloadData()
      }
    })
    present(alert, animated: true)
  }

  // MARK: - UITableViewDataSource
  func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
    return Model.shared.count
  }
  
  func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
    let cell = tableView.dequeueReusableCell(withIdentifier: "cell", for: indexPath)
    
    let notitie = Model.shared.notitie(op: indexPath.row)
    cell.textLabel?.text = notitie.titel
    cell.detailTextLabel?.text = DateFormatter.localizedString(from: notitie.datum as Date!, dateStyle: .long, timeStyle: .medium)
    
    return cell
  }
  
  // MARK: - UITableViewDelegate

  func tableView(_ tableView: UITableView, editActionsForRowAt indexPath: IndexPath) -> [UITableViewRowAction]? {
    let wijzigAction = UITableViewRowAction(style: .normal, title: "Wijzig") {
      actie, indexPath in
        self.wijzig(notitie: Model.shared.notitie(op: indexPath.row))
    }

    let verwijderAction = UITableViewRowAction(style: .destructive, title: "Verwijder") {
      actie, indexPath in
      self.verwijder(notitie: Model.shared.notitie(op: indexPath.row))
    }
    
    return [wijzigAction, verwijderAction]
  }
  
}

